@@ -29,7 +29,6 @@
 from __future__ import annotations
 
 import hashlib
-import logging
 import time
 import typing as t
 
@@ -39,8 +38,6 @@ if t.TYPE_CHECKING:
     from analytix.secrets import Secrets
     from analytix.types import DataHeadersT
 
-log = logging.getLogger(__name__)
-
 
 def create_state() -> str:
     """Create a random state for requests.
@@ -52,12 +49,14 @@ def create_state() -> str:
     return hashlib.sha256(f"{time.time()}".encode("utf-8")).hexdigest()
 
 
-def auth_url_and_state(secrets: Secrets) -> tuple[str, str]:
+def auth_url_and_state(secrets: Secrets, redirect_uri: str) -> tuple[str, str]:
     """Get the authorisation URL and the state.
 
     Args:
         secrets:
             The project secrets from the Google Developers Console.
+        redirect_uri:
+            The URI to redirect to after authorisation.
 
     Returns:
         A tuple containing the generated URL and state.
@@ -67,14 +66,16 @@ def auth_url_and_state(secrets: Secrets) -> tuple[str, str]:
     url = secrets.auth_uri + (
         "?response_type=code"
         f"&client_id={secrets.client_id}"
-        f"&redirect_uri={secrets.redirect_uris[0]}"
+        f"&redirect_uri={redirect_uri}"
         f"&scope={'+'.join(analytix.API_SCOPES)}"
         f"&state={state}"
     )
     return url, state
 
 
-def access_data_and_headers(code: str, secrets: Secrets) -> DataHeadersT:
+def access_data_and_headers(
+    code: str, secrets: Secrets, redirect_uri: str
+) -> DataHeadersT:
     """Get the required data and headers for retrieving tokens from
     the YouTube Token Endpoint.
 
@@ -83,6 +84,8 @@ def access_data_and_headers(code: str, secrets: Secrets) -> DataHeadersT:
             The authorisation code.
         secrets:
             The project secrets from the Google Developers Console.
+        redirect_uri:
+            The URI to redirect to after authorisation.
 
     Returns:
         A tuple containing the data and headers.
@@ -93,7 +96,7 @@ def access_data_and_headers(code: str, secrets: Secrets) -> DataHeadersT:
         "client_secret": secrets.client_secret,
         "grant_type": "authorization_code",
         "code": code,
-        "redirect_uri": secrets.redirect_uris[0],
+        "redirect_uri": redirect_uri,
     }
     headers = {"Content-Type": "application/x-www-form-urlencoded"}
     return data, headers
